bayespy.inference.vmp.transformations.RotateGaussianMarkovChain
===============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotateGaussianMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotateGaussianMarkovChain.__init__
      ~RotateGaussianMarkovChain.bound
      ~RotateGaussianMarkovChain.get_bound_terms
      ~RotateGaussianMarkovChain.nodes
      ~RotateGaussianMarkovChain.rotate
      ~RotateGaussianMarkovChain.setup
   
   

   
   
   